#
# Copyright (C) 2020-2021 MicroSys Electronics GmbH
#

FILESEXTRAPATHS_prepend := "${THISDIR}/${PN}:"
PATCHTOOL = "git"
PATCH_COMMIT_FUNCTIONS = "1"

# Currently, OPTEE doesn't compile:
#DEPENDS_remove = "optee-os-qoriq"
#BUILD_OPTEE := "false"
#BUILD_FUSE := "false"
#BUILD_SECURE := "false"
#BUILD_OTA := "false"

#ATF_BRANCH = "integration"
SRCREV = "340b20bcb50ece2877a272592a514b3e872e28d7"

python do_patch_prepend() {
    if d.getVar('PATCHTOOL') == 'git':
        srcsubdir = d.getVar('S')
        bb.process.run('git config am.threeWay true', cwd=srcsubdir)
        bb.process.run('git config am.keepcr true', cwd=srcsubdir)
        bb.process.run('git config apply.whitespace fix', cwd=srcsubdir)
        bb.process.run('git config apply.ignoreWhitespace change', cwd=srcsubdir)
}


BOOTTYPE += "mpxls1046_ram_4gb_crx05_sd mpxls1046_ram_4gb_crx05_qspi mpxls1046_ram_2gb_crx05_sd mpxls1046_ram_2gb_crx05_qspi mpxls1046_crx06_sd mpxls1046_crx06_qspi mpxls1088_crx05_sd mpxls1088_crx05_qspi RCWSD RCWXSPI mpxls1088_crx06_sd mpxls1088_crx06_qspi mpxls1088_crx06_qsgmii_sd mpxls1088_crx06_qsgmii_qspi"

python () {
    if d.getVar('MACHINE') == 'mpxls1046crx05ram2gb':
        d.setVar('chassistype', 'ls104x_1012')
}
python () {
    if d.getVar('MACHINE') == 'mpxls1046crx05ram4gb':
        d.setVar('chassistype', 'ls104x_1012')
}
python () {
    if d.getVar('MACHINE') == 'mpxls1046crx06':
        d.setVar('chassistype', 'ls104x_1012')
}
python () {
    if d.getVar('MACHINE').startswith('mpxls1043'):
        d.setVar('chassistype', 'ls104x_1012')
}
python () {
    if d.getVar('MACHINE') == 'mpxls1088crx05':
        d.setVar('chassistype', 'ls104x_1012')
}
python () {
    if d.getVar('MACHINE') == 'mpxls1088crx06':
        d.setVar('chassistype', 'ls104x_1012')
}
python () {
    if d.getVar('MACHINE') == 'mpxls1088crx06qsgmii':
        d.setVar('chassistype', 'ls104x_1012')
}
python () {
    if d.getVar('PLATFORM') == 'mpxls1046ram2gbcrx05':
        d.setVar('PLATFORM_MICROSYS', 'mpxls1046_ram_2gb_crx05')
}
python () {
    if d.getVar('PLATFORM') == 'mpxls1046ram4gbcrx05':
        d.setVar('PLATFORM_MICROSYS', 'mpxls1046_ram_4gb_crx05')
}
python () {
    if d.getVar('PLATFORM') == 'mpxls1046crx06':
        d.setVar('PLATFORM_MICROSYS', 'mpxls1046_ram_4gb_crx06')
}
python () {
    if d.getVar('PLATFORM') == 'mpxls1088crx05':
        d.setVar('PLATFORM_MICROSYS', 'mpxls1088_crx05')
}
python () {
    if d.getVar('PLATFORM') == 'mpxls1088crx06':
        d.setVar('PLATFORM_MICROSYS', 'mpxls1088_crx06')
}
python () {
    if d.getVar('PLATFORM') == 'mpxls1088crx06qsgmii':
        d.setVar('PLATFORM_MICROSYS', 'mpxls1088_crx06')
}
python () {
    if d.getVar('PLATFORM') == 'mpxls1028crx07':
        d.setVar('PLATFORM_MICROSYS', 'mpxls1028crx07')
}
python () {
    if d.getVar('PLATFORM') == 'mpxlx2160acrx08':
        d.setVar('PLATFORM_MICROSYS', 'mpxlx2160acrx08')
}
python () {
    if d.getVar('PLATFORM') == 'mpxlx2160acrx08ai':
        d.setVar('PLATFORM_MICROSYS', 'mpxlx2160acrx08')
}
uboot_boot ?= "${DEPLOY_DIR_IMAGE}/u-boot.bin"

do_compile() {
    export LIBPATH="${RECIPE_SYSROOT_NATIVE}"
    install -d ${S}/include/tools_share/openssl
    cp -r ${RECIPE_SYSROOT}/usr/include/openssl/*   ${S}/include/tools_share/openssl
    ${RECIPE_SYSROOT_NATIVE}/usr/bin/cst/gen_keys 1024

    if [ "${BUILD_FUSE}" = "true" ]; then
       ${RECIPE_SYSROOT_NATIVE}/usr/bin/cst/gen_fusescr ${RECIPE_SYSROOT_NATIVE}/usr/bin/cst/input_files/gen_fusescr/${chassistype}/input_fuse_file
       fuseopt="fip_fuse FUSE_PROG=1 FUSE_PROV_FILE=fuse_scr.bin"
    fi
    if [ "${BUILD_SECURE}" = "true" ]; then
        secureopt="TRUSTED_BOARD_BOOT=1 ${ddrphyopt} CST_DIR=${RECIPE_SYSROOT_NATIVE}/usr/bin/cst"
        secext="_sec"
        bl33="${uboot_boot_sec}"
        if [ ${chassistype} = ls104x_1012 ]; then
            rcwtemp="${rcwsec}"
        else
            rcwtemp="${rcw}"
        fi
    else
        bl33="${DEPLOY_DIR_IMAGE}/u-boot.bin"
        rcwtemp="${rcw}"
    fi

    if [ "${BUILD_OPTEE}" = "true" ]; then
        bl32="${DEPLOY_DIR_IMAGE}/optee/tee_${MACHINE}.bin"
        bl32opt="BL32=${bl32}"
        spdopt="SPD=opteed"
    fi
    if [ -f ${DEPLOY_DIR_IMAGE}/ddr-phy/ddr4_pmu_train_dmem.bin ]; then
        cp ${DEPLOY_DIR_IMAGE}/ddr-phy/*.bin ${S}/
    fi

    for d in ${BOOTTYPE}; do
        case $d in
        mpxls1046_ram_4gb_crx05_sd)
            rcwimg="${mpxls1046_ram_4gb_crx05_sd}.bin"
			bm="sd"
            ;;
        mpxls1046_ram_4gb_crx05_qspi)
            rcwimg="${mpxls1046_ram_4gb_crx05_qspi}.bin"
			bm="qspi"
            ;;
        mpxls1046_ram_2gb_crx05_sd)
            rcwimg="${mpxls1046_ram_2gb_crx05_sd}.bin"
			bm="sd"
            ;;
        mpxls1046_ram_2gb_crx05_qspi)
            rcwimg="${mpxls1046_ram_2gb_crx05_qspi}.bin"
			bm="qspi"
            ;;
        mpxls1046_crx06_sd)
            rcwimg="${mpxls1046_crx06_sd}.bin"
			bm="sd"
            ;;
        mpxls1046_crx06_qspi)
            rcwimg="${mpxls1046_crx06_qspi}.bin"
			bm="qspi"
            ;;
        mpxls1088_crx05_sd)
            rcwimg="${mpxls1088_crx05_sd}.bin"
			bm="sd"
            ;;
        mpxls1088_crx05_qspi)
            rcwimg="${mpxls1088_crx05_qspi}.bin"
			bm="qspi"
            ;;
        RCWSD)
            rcwimg="${RCWSD}.bin"
			bm="sd"
            ;;
        RCWXSPI)
            rcwimg="${RCWXSPI}.bin"
			bm="flexspi_nor"
            ;;
        sd)
            rcwimg="${RCWSD}.bin"
			bm="sd"
			PLATFORM_MICROSYS=${ATF_PLATFORM}_${bm}
            ;;
        qspi)
            rcwimg="${RCWQSPI}.bin"
			bm="qspi"
			PLATFORM_MICROSYS=${ATF_PLATFORM}_${bm}
            ;;
        nand)
            rcwimg="${RCWNAND}.bin"
			bm="nand"
			PLATFORM_MICROSYS=${ATF_PLATFORM}_${bm}
            ;;
        mpxls1088_crx06_sd)
            rcwimg="${mpxls1088_crx06_sd}.bin"
			bm="sd"
            ;;
        mpxls1088_crx06_qspi)
            rcwimg="${mpxls1088_crx06_qspi}.bin"
			bm="qspi"
            ;;
        mpxls1088_crx06_qsgmii_sd)
            rcwimg="${mpxls1088_crx06_qsgmii_sd}.bin"
			bm="sd"
            ;;
        mpxls1088_crx06_qsgmii_qspi)
            rcwimg="${mpxls1088_crx06_qsgmii_qspi}.bin"
			bm="qspi"
            ;;
        esac


if [ -f "${DEPLOY_DIR_IMAGE}/rcw/${rcwimg}" ]; then
	oe_runmake V=1 -C ${S} realclean

# MPXLS1043 has 6 different configs:
# CPU : 1000 MHz, serdes : pcie or msata, boot mode: nand, qspi, sd.

    # We are doing the same for every mpxls1043 machine
    if [ "${MACHINE}" = "mpxls1043ac1000msatacrx05" ] \
    || [ "${MACHINE}" = "mpxls1043ac1000pciecrx05" ] \
    || [ "${MACHINE}" = "mpxls1043ac1600msatacrx05" ] \
    || [ "${MACHINE}" = "mpxls1043ac1600pciecrx05" ] ; then
		oe_runmake V=1 -C ${S} all fip pbl PLAT=${PLATFORM_MICROSYS} BOOT_MODE=${bm} RCW=${DEPLOY_DIR_IMAGE}/rcw/${rcwimg} BL33=${bl33} ${bl32opt} ${spdopt} ${secureopt} ${fuseopt}
		cp -r ${S}/build/${PLATFORM_MICROSYS}/release/bl2_${bm}.pbl ${S}
		cp -r ${S}/build/${PLATFORM_MICROSYS}/release/fip.bin ${S}
		if [ "${BUILD_FUSE}" = "true" ]; then
			cp -f ${S}/build/${PLATFORM_MICROSYS}/release/fuse_fip.bin ${S}
		fi

    else
                oe_runmake V=1 -C ${S} all fip pbl PLAT=${PLATFORM_MICROSYS} BOOT_MODE=${bm} RCW=${DEPLOY_DIR_IMAGE}/rcw/${rcwimg} BL33=${bl33} ${bl32opt} ${spdopt} ${secureopt} ${fuseopt}
                cp -r ${S}/build/${PLATFORM_MICROSYS}/release/bl2_${bm}*.pbl ${S}
                cp -r ${S}/build/${PLATFORM_MICROSYS}/release/fip.bin ${S}
                if [ "${BUILD_FUSE}" = "true" ]; then
                    cp -f ${S}/build/${PLATFORM_MICROSYS}/release/fuse_fip.bin ${S}
                fi
	fi
fi
        rcwimg=""
        uefiboot=""
    done
}

do_install_append() {
    if [ -f "${S}/fip_ddr_sec.bin" ]; then
        cp -r ${S}/fip_ddr_sec.bin ${bm}/boot/atf/fip_ddr_sec.bin
    fi
}

#do_deploy_prepend() {
#
#	if [ ${PLATFORM} = mpxls1043crx05 ]; then
#		cp -r ${S}/bl2_nand.pbl ${D}/boot/atf/bl2_nand.pbl
#		cp -r ${S}/bl2_qspi.pbl ${D}/boot/atf/bl2_qspi.pbl
#		cp -r ${S}/bl2_sd.pbl ${D}/boot/atf/bl2_sd.pbl
#
#	fi
#
#}

do_deploy_append() {
    cp ${D}/boot/atf/fip.bin ${DEPLOYDIR}/atf/fip_uboot.bin
}

SRC_URI += "file://0001-mpxlx2160-added-platform.patch \
			file://0002-mpxls1046-added-platform.patch \
			file://0003-mpxls1043-added-platform.patch \
			file://0004-mpxls1028-added-platform.patch \
			file://0005-mpxls1088-added-platform.patch \
			file://0006-mpxlx2160-Updated-DRAM-Timing-parameters.patch \
			file://0007-Added-flash-type-MT25QU128A.patch \
			file://0008-mpxlx2160-fixed-support-for-CONFIG_DDR_NODIMM.patch \
			file://0009-Fixed-multiple-ifdefs-error.patch \
			file://0010-Added-loading-of-1D-2D-training-register-values-from.patch \
			file://0011-mpxlx2160-Disabled-WARM_BOOT-define.patch \
			file://0012-localversion-microsys-added-3.0-Added.patch \
			file://0013-mpxls1088-new-DRAM-Timings.patch \
			"
